@@ -352,7 +352,7 @@ class NnMixer:
             for feature in transformed_output_vectors:
                 if feature not in output_trasnformed_vectors:
                     output_trasnformed_vectors[feature] = []
-                output_trasnformed_vectors[feature] += [transformed_output_vectors[feature]]
+                output_trasnformed_vectors[feature].append(transformed_output_vectors[feature])
 
         predictions = {}
         for k, output_column in enumerate(list(output_trasnformed_vectors.keys())):
